package com.xkrs.controller;

import com.xkrs.dao.PictureDao;
import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.model.entity.PictureEntity;
import com.xkrs.model.entity.SpecEntity;
import com.xkrs.model.qo.FileQo;
import com.xkrs.model.qo.PictureQo;
import com.xkrs.service.PictureService;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.Locale;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/20 16:01
 */
@RestController
public class PictureController {

    @Resource
    private PictureService pictureService;

    @Resource
    private PictureDao pictureDao;

    /**
     * 上传图片
     */
    @PostMapping("/insertPicture")
    public String insertPicture(PictureQo pictureQo, @RequestParam("filePicture") MultipartFile filePicture) throws IOException {
        return pictureService.insertPicture(pictureQo, filePicture);
    }

    /**
     * 查询图片
     */
    @PostMapping("/selectPicture")
    public String selectPicture(@RequestBody PictureQo pictureQo) throws IOException, InvalidFormatException {
        Locale locale = LocaleContextHolder.getLocale();
        String lotNo = pictureQo.getLotNo();
        String machineNo = pictureQo.getMachineNo();
        String materialNo = pictureQo.getMaterialNo();
        String modelNo = pictureQo.getModelNo();
        String partNo = pictureQo.getPartNo();
        PictureEntity pictureEntity = pictureDao.selectPicture(lotNo, machineNo, materialNo, modelNo, partNo).get();
        if (pictureEntity == null) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时没有该零件的图片！", locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, pictureEntity, locale);
    }
}
